@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 from pathlib import Path
 
@@ -5,7 +7,7 @@ import git
 from git import Repo
 from typing_extensions import Generator
 
-from patchwork.common.utils import get_current_branch
+from patchwork.common.utils.utils import get_current_branch
 from patchwork.logger import logger
 from patchwork.step import Step
 
@@ -18,7 +20,10 @@ def get_slug_from_remote_url(remote_url: str) -> str:
     else:
         potential_slug = "/".join(remote_url.split("/")[-2:])
 
-    return potential_slug.removesuffix(".git")
+    if potential_slug.endswith(".git"):
+        potential_slug = potential_slug[:-4]
+
+    return potential_slug
 
 
 @contextlib.contextmanager
@@ -128,22 +133,26 @@ class CommitChanges(Step):
             raise ValueError("Both branch_prefix and branch_suffix cannot be empty")
 
     def run(self) -> dict:
-        repo = git.Repo(Path.cwd(), search_parent_directories=True)
-        if not self.enabled:
+        cwd = Path.cwd()
+        repo = git.Repo(cwd, search_parent_directories=True)
+        repo_dir_path = Path(repo.working_tree_dir)
+        repo_changed_files = {repo_dir_path / item.a_path for item in repo.index.diff(None)}
+        repo_untracked_files = {repo_dir_path / item for item in repo.untracked_files}
+        modified_files = {Path(modified_code_file["path"]).resolve() for modified_code_file in self.modified_code_files}
+        true_modified_files = modified_files.intersection(repo_changed_files.union(repo_untracked_files))
+        if not self.enabled or len(true_modified_files) < 1:
             logger.debug("Branch creation is disabled.")
             from_branch = get_current_branch(repo)
             from_branch_name = from_branch.name if not from_branch.is_remote() else from_branch.remote_head
             return dict(target_branch=from_branch_name)
 
-        modified_files = {modified_code_file["path"] for modified_code_file in self.modified_code_files}
-
         with transitioning_branches(
             repo, branch_prefix=self.branch_prefix, branch_suffix=self.branch_suffix, force=self.force
         ) as (
             from_branch,
             to_branch,
         ):
-            for modified_file in modified_files:
+            for modified_file in true_modified_files:
                 repo.git.add(modified_file)
                 commit_with_msg(repo, f"Patched {modified_file}")
 
